# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations


import proto  # type: ignore


__protobuf__ = proto.module(
    package="google.ads.googleads.v20.errors",
    marshal="google.ads.googleads.v20",
    manifest={
        "AccessInvitationErrorEnum",
    },
)


class AccessInvitationErrorEnum(proto.Message):
    r"""Container for enum describing possible AccessInvitation
    errors.

    """

    class AccessInvitationError(proto.Enum):
        r"""Enum describing possible AccessInvitation errors.

        Values:
            UNSPECIFIED (0):
                Enum unspecified.
            UNKNOWN (1):
                The received error code is not known in this
                version.
            INVALID_EMAIL_ADDRESS (2):
                The email address is invalid for sending an
                invitation.
            EMAIL_ADDRESS_ALREADY_HAS_ACCESS (3):
                Email address already has access to this
                customer.
            INVALID_INVITATION_STATUS (4):
                Invalid invitation status for the operation.
            GOOGLE_CONSUMER_ACCOUNT_NOT_ALLOWED (5):
                Email address cannot be like
                abc+foo@google.com.
            INVALID_INVITATION_ID (6):
                Invalid invitation ID.
            EMAIL_ADDRESS_ALREADY_HAS_PENDING_INVITATION (7):
                Email address already has a pending
                invitation.
            PENDING_INVITATIONS_LIMIT_EXCEEDED (8):
                Pending invitation limit exceeded for the
                customer.
            EMAIL_DOMAIN_POLICY_VIOLATED (9):
                Email address doesn't conform to the email
                domain policy. See
                https://support.google.com/google-ads/answer/2375456
        """

        UNSPECIFIED = 0
        UNKNOWN = 1
        INVALID_EMAIL_ADDRESS = 2
        EMAIL_ADDRESS_ALREADY_HAS_ACCESS = 3
        INVALID_INVITATION_STATUS = 4
        GOOGLE_CONSUMER_ACCOUNT_NOT_ALLOWED = 5
        INVALID_INVITATION_ID = 6
        EMAIL_ADDRESS_ALREADY_HAS_PENDING_INVITATION = 7
        PENDING_INVITATIONS_LIMIT_EXCEEDED = 8
        EMAIL_DOMAIN_POLICY_VIOLATED = 9


__all__ = tuple(sorted(__protobuf__.manifest))
