# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .account_budget_proposal_service import (
    AccountBudgetProposalOperation,
    MutateAccountBudgetProposalRequest,
    MutateAccountBudgetProposalResponse,
    MutateAccountBudgetProposalResult,
)
from .account_link_service import (
    AccountLinkOperation,
    CreateAccountLinkRequest,
    CreateAccountLinkResponse,
    MutateAccountLinkRequest,
    MutateAccountLinkResponse,
    MutateAccountLinkResult,
)
from .ad_group_ad_label_service import (
    AdGroupAdLabelOperation,
    MutateAdGroupAdLabelResult,
    MutateAdGroupAdLabelsRequest,
    MutateAdGroupAdLabelsResponse,
)
from .ad_group_ad_service import (
    AdGroupAdOperation,
    AssetsWithFieldType,
    MutateAdGroupAdResult,
    MutateAdGroupAdsRequest,
    MutateAdGroupAdsResponse,
    RemoveAutomaticallyCreatedAssetsRequest,
)
from .ad_group_asset_service import (
    AdGroupAssetOperation,
    MutateAdGroupAssetResult,
    MutateAdGroupAssetsRequest,
    MutateAdGroupAssetsResponse,
)
from .ad_group_asset_set_service import (
    AdGroupAssetSetOperation,
    MutateAdGroupAssetSetResult,
    MutateAdGroupAssetSetsRequest,
    MutateAdGroupAssetSetsResponse,
)
from .ad_group_bid_modifier_service import (
    AdGroupBidModifierOperation,
    MutateAdGroupBidModifierResult,
    MutateAdGroupBidModifiersRequest,
    MutateAdGroupBidModifiersResponse,
)
from .ad_group_criterion_customizer_service import (
    AdGroupCriterionCustomizerOperation,
    MutateAdGroupCriterionCustomizerResult,
    MutateAdGroupCriterionCustomizersRequest,
    MutateAdGroupCriterionCustomizersResponse,
)
from .ad_group_criterion_label_service import (
    AdGroupCriterionLabelOperation,
    MutateAdGroupCriterionLabelResult,
    MutateAdGroupCriterionLabelsRequest,
    MutateAdGroupCriterionLabelsResponse,
)
from .ad_group_criterion_service import (
    AdGroupCriterionOperation,
    MutateAdGroupCriteriaRequest,
    MutateAdGroupCriteriaResponse,
    MutateAdGroupCriterionResult,
)
from .ad_group_customizer_service import (
    AdGroupCustomizerOperation,
    MutateAdGroupCustomizerResult,
    MutateAdGroupCustomizersRequest,
    MutateAdGroupCustomizersResponse,
)
from .ad_group_label_service import (
    AdGroupLabelOperation,
    MutateAdGroupLabelResult,
    MutateAdGroupLabelsRequest,
    MutateAdGroupLabelsResponse,
)
from .ad_group_service import (
    AdGroupOperation,
    MutateAdGroupResult,
    MutateAdGroupsRequest,
    MutateAdGroupsResponse,
)
from .ad_parameter_service import (
    AdParameterOperation,
    MutateAdParameterResult,
    MutateAdParametersRequest,
    MutateAdParametersResponse,
)
from .ad_service import (
    AdOperation,
    MutateAdResult,
    MutateAdsRequest,
    MutateAdsResponse,
)
from .asset_generation_service import (
    AssetGenerationExistingContext,
    FinalUrlImageGenerationInput,
    FreeformImageGenerationInput,
    GeneratedImage,
    GeneratedText,
    GenerateImagesRequest,
    GenerateImagesResponse,
    GenerateTextRequest,
    GenerateTextResponse,
    ProductRecontextGenerationImageInput,
    SourceImage,
)
from .asset_group_asset_service import (
    AssetGroupAssetOperation,
    MutateAssetGroupAssetResult,
    MutateAssetGroupAssetsRequest,
    MutateAssetGroupAssetsResponse,
)
from .asset_group_listing_group_filter_service import (
    AssetGroupListingGroupFilterOperation,
    MutateAssetGroupListingGroupFilterResult,
    MutateAssetGroupListingGroupFiltersRequest,
    MutateAssetGroupListingGroupFiltersResponse,
)
from .asset_group_service import (
    AssetGroupOperation,
    MutateAssetGroupResult,
    MutateAssetGroupsRequest,
    MutateAssetGroupsResponse,
)
from .asset_group_signal_service import (
    AssetGroupSignalOperation,
    MutateAssetGroupSignalResult,
    MutateAssetGroupSignalsRequest,
    MutateAssetGroupSignalsResponse,
)
from .asset_service import (
    AssetOperation,
    MutateAssetResult,
    MutateAssetsRequest,
    MutateAssetsResponse,
)
from .asset_set_asset_service import (
    AssetSetAssetOperation,
    MutateAssetSetAssetResult,
    MutateAssetSetAssetsRequest,
    MutateAssetSetAssetsResponse,
)
from .asset_set_service import (
    AssetSetOperation,
    MutateAssetSetResult,
    MutateAssetSetsRequest,
    MutateAssetSetsResponse,
)
from .audience_insights_service import (
    AudienceCompositionAttribute,
    AudienceCompositionAttributeCluster,
    AudienceCompositionMetrics,
    AudienceCompositionSection,
    AudienceOverlapItem,
    DimensionOverlapResult,
    GenerateAudienceCompositionInsightsRequest,
    GenerateAudienceCompositionInsightsResponse,
    GenerateAudienceOverlapInsightsRequest,
    GenerateAudienceOverlapInsightsResponse,
    GenerateInsightsFinderReportRequest,
    GenerateInsightsFinderReportResponse,
    GenerateSuggestedTargetingInsightsRequest,
    GenerateSuggestedTargetingInsightsResponse,
    GenerateTargetingSuggestionMetricsRequest,
    GenerateTargetingSuggestionMetricsResponse,
    InsightsAudience,
    InsightsAudienceAttributeGroup,
    InsightsAudienceDefinition,
    InsightsAudienceDescription,
    ListAudienceInsightsAttributesRequest,
    ListAudienceInsightsAttributesResponse,
    ListInsightsEligibleDatesRequest,
    ListInsightsEligibleDatesResponse,
    TargetingSuggestionMetrics,
)
from .audience_service import (
    AudienceOperation,
    MutateAudienceResult,
    MutateAudiencesRequest,
    MutateAudiencesResponse,
)
from .automatically_created_asset_removal_service import (
    RemoveCampaignAutomaticallyCreatedAssetOperation,
    RemoveCampaignAutomaticallyCreatedAssetRequest,
    RemoveCampaignAutomaticallyCreatedAssetResponse,
)
from .batch_job_service import (
    AddBatchJobOperationsRequest,
    AddBatchJobOperationsResponse,
    BatchJobOperation,
    BatchJobResult,
    ListBatchJobResultsRequest,
    ListBatchJobResultsResponse,
    MutateBatchJobRequest,
    MutateBatchJobResponse,
    MutateBatchJobResult,
    RunBatchJobRequest,
)
from .bidding_data_exclusion_service import (
    BiddingDataExclusionOperation,
    MutateBiddingDataExclusionsRequest,
    MutateBiddingDataExclusionsResponse,
    MutateBiddingDataExclusionsResult,
)
from .bidding_seasonality_adjustment_service import (
    BiddingSeasonalityAdjustmentOperation,
    MutateBiddingSeasonalityAdjustmentsRequest,
    MutateBiddingSeasonalityAdjustmentsResponse,
    MutateBiddingSeasonalityAdjustmentsResult,
)
from .bidding_strategy_service import (
    BiddingStrategyOperation,
    MutateBiddingStrategiesRequest,
    MutateBiddingStrategiesResponse,
    MutateBiddingStrategyResult,
)
from .billing_setup_service import (
    BillingSetupOperation,
    MutateBillingSetupRequest,
    MutateBillingSetupResponse,
    MutateBillingSetupResult,
)
from .brand_suggestion_service import (
    BrandSuggestion,
    SuggestBrandsRequest,
    SuggestBrandsResponse,
)
from .campaign_asset_service import (
    CampaignAssetOperation,
    MutateCampaignAssetResult,
    MutateCampaignAssetsRequest,
    MutateCampaignAssetsResponse,
)
from .campaign_asset_set_service import (
    CampaignAssetSetOperation,
    MutateCampaignAssetSetResult,
    MutateCampaignAssetSetsRequest,
    MutateCampaignAssetSetsResponse,
)
from .campaign_bid_modifier_service import (
    CampaignBidModifierOperation,
    MutateCampaignBidModifierResult,
    MutateCampaignBidModifiersRequest,
    MutateCampaignBidModifiersResponse,
)
from .campaign_budget_service import (
    CampaignBudgetOperation,
    MutateCampaignBudgetResult,
    MutateCampaignBudgetsRequest,
    MutateCampaignBudgetsResponse,
)
from .campaign_conversion_goal_service import (
    CampaignConversionGoalOperation,
    MutateCampaignConversionGoalResult,
    MutateCampaignConversionGoalsRequest,
    MutateCampaignConversionGoalsResponse,
)
from .campaign_criterion_service import (
    CampaignCriterionOperation,
    MutateCampaignCriteriaRequest,
    MutateCampaignCriteriaResponse,
    MutateCampaignCriterionResult,
)
from .campaign_customizer_service import (
    CampaignCustomizerOperation,
    MutateCampaignCustomizerResult,
    MutateCampaignCustomizersRequest,
    MutateCampaignCustomizersResponse,
)
from .campaign_draft_service import (
    CampaignDraftOperation,
    ListCampaignDraftAsyncErrorsRequest,
    ListCampaignDraftAsyncErrorsResponse,
    MutateCampaignDraftResult,
    MutateCampaignDraftsRequest,
    MutateCampaignDraftsResponse,
    PromoteCampaignDraftRequest,
)
from .campaign_goal_config_service import (
    CampaignGoalConfigOperation,
    MutateCampaignGoalConfigResult,
    MutateCampaignGoalConfigsRequest,
    MutateCampaignGoalConfigsResponse,
)
from .campaign_group_service import (
    CampaignGroupOperation,
    MutateCampaignGroupResult,
    MutateCampaignGroupsRequest,
    MutateCampaignGroupsResponse,
)
from .campaign_label_service import (
    CampaignLabelOperation,
    MutateCampaignLabelResult,
    MutateCampaignLabelsRequest,
    MutateCampaignLabelsResponse,
)
from .campaign_lifecycle_goal_service import (
    CampaignLifecycleGoalOperation,
    ConfigureCampaignLifecycleGoalsRequest,
    ConfigureCampaignLifecycleGoalsResponse,
    ConfigureCampaignLifecycleGoalsResult,
)
from .campaign_service import (
    BrandCampaignAssets,
    CampaignOperation,
    EnablementResult,
    EnableOperation,
    EnablePMaxBrandGuidelinesRequest,
    EnablePMaxBrandGuidelinesResponse,
    MutateCampaignResult,
    MutateCampaignsRequest,
    MutateCampaignsResponse,
)
from .campaign_shared_set_service import (
    CampaignSharedSetOperation,
    MutateCampaignSharedSetResult,
    MutateCampaignSharedSetsRequest,
    MutateCampaignSharedSetsResponse,
)
from .content_creator_insights_service import (
    GenerateCreatorInsightsRequest,
    GenerateCreatorInsightsResponse,
    GenerateTrendingInsightsRequest,
    GenerateTrendingInsightsResponse,
    SearchAudience,
    SearchTopics,
    TrendInsight,
    TrendInsightMetrics,
    YouTubeChannelInsights,
    YouTubeCreatorInsights,
    YouTubeMetrics,
)
from .conversion_action_service import (
    ConversionActionOperation,
    MutateConversionActionResult,
    MutateConversionActionsRequest,
    MutateConversionActionsResponse,
)
from .conversion_adjustment_upload_service import (
    ConversionAdjustment,
    ConversionAdjustmentResult,
    GclidDateTimePair,
    RestatementValue,
    UploadConversionAdjustmentsRequest,
    UploadConversionAdjustmentsResponse,
)
from .conversion_custom_variable_service import (
    ConversionCustomVariableOperation,
    MutateConversionCustomVariableResult,
    MutateConversionCustomVariablesRequest,
    MutateConversionCustomVariablesResponse,
)
from .conversion_goal_campaign_config_service import (
    ConversionGoalCampaignConfigOperation,
    MutateConversionGoalCampaignConfigResult,
    MutateConversionGoalCampaignConfigsRequest,
    MutateConversionGoalCampaignConfigsResponse,
)
from .conversion_upload_service import (
    CallConversion,
    CallConversionResult,
    CartData,
    ClickConversion,
    ClickConversionResult,
    CustomVariable,
    ExternalAttributionData,
    SessionAttributeKeyValuePair,
    SessionAttributesKeyValuePairs,
    UploadCallConversionsRequest,
    UploadCallConversionsResponse,
    UploadClickConversionsRequest,
    UploadClickConversionsResponse,
)
from .conversion_value_rule_service import (
    ConversionValueRuleOperation,
    MutateConversionValueRuleResult,
    MutateConversionValueRulesRequest,
    MutateConversionValueRulesResponse,
)
from .conversion_value_rule_set_service import (
    ConversionValueRuleSetOperation,
    MutateConversionValueRuleSetResult,
    MutateConversionValueRuleSetsRequest,
    MutateConversionValueRuleSetsResponse,
)
from .custom_audience_service import (
    CustomAudienceOperation,
    MutateCustomAudienceResult,
    MutateCustomAudiencesRequest,
    MutateCustomAudiencesResponse,
)
from .custom_conversion_goal_service import (
    CustomConversionGoalOperation,
    MutateCustomConversionGoalResult,
    MutateCustomConversionGoalsRequest,
    MutateCustomConversionGoalsResponse,
)
from .custom_interest_service import (
    CustomInterestOperation,
    MutateCustomInterestResult,
    MutateCustomInterestsRequest,
    MutateCustomInterestsResponse,
)
from .customer_asset_service import (
    CustomerAssetOperation,
    MutateCustomerAssetResult,
    MutateCustomerAssetsRequest,
    MutateCustomerAssetsResponse,
)
from .customer_asset_set_service import (
    CustomerAssetSetOperation,
    MutateCustomerAssetSetResult,
    MutateCustomerAssetSetsRequest,
    MutateCustomerAssetSetsResponse,
)
from .customer_client_link_service import (
    CustomerClientLinkOperation,
    MutateCustomerClientLinkRequest,
    MutateCustomerClientLinkResponse,
    MutateCustomerClientLinkResult,
)
from .customer_conversion_goal_service import (
    CustomerConversionGoalOperation,
    MutateCustomerConversionGoalResult,
    MutateCustomerConversionGoalsRequest,
    MutateCustomerConversionGoalsResponse,
)
from .customer_customizer_service import (
    CustomerCustomizerOperation,
    MutateCustomerCustomizerResult,
    MutateCustomerCustomizersRequest,
    MutateCustomerCustomizersResponse,
)
from .customer_label_service import (
    CustomerLabelOperation,
    MutateCustomerLabelResult,
    MutateCustomerLabelsRequest,
    MutateCustomerLabelsResponse,
)
from .customer_lifecycle_goal_service import (
    ConfigureCustomerLifecycleGoalsRequest,
    ConfigureCustomerLifecycleGoalsResponse,
    ConfigureCustomerLifecycleGoalsResult,
    CustomerLifecycleGoalOperation,
)
from .customer_manager_link_service import (
    CustomerManagerLinkOperation,
    MoveManagerLinkRequest,
    MoveManagerLinkResponse,
    MutateCustomerManagerLinkRequest,
    MutateCustomerManagerLinkResponse,
    MutateCustomerManagerLinkResult,
)
from .customer_negative_criterion_service import (
    CustomerNegativeCriterionOperation,
    MutateCustomerNegativeCriteriaRequest,
    MutateCustomerNegativeCriteriaResponse,
    MutateCustomerNegativeCriteriaResult,
)
from .customer_service import (
    CreateCustomerClientRequest,
    CreateCustomerClientResponse,
    CustomerOperation,
    ListAccessibleCustomersRequest,
    ListAccessibleCustomersResponse,
    MutateCustomerRequest,
    MutateCustomerResponse,
    MutateCustomerResult,
)
from .customer_sk_ad_network_conversion_value_schema_service import (
    CustomerSkAdNetworkConversionValueSchemaOperation,
    MutateCustomerSkAdNetworkConversionValueSchemaRequest,
    MutateCustomerSkAdNetworkConversionValueSchemaResponse,
    MutateCustomerSkAdNetworkConversionValueSchemaResult,
)
from .customer_user_access_invitation_service import (
    CustomerUserAccessInvitationOperation,
    MutateCustomerUserAccessInvitationRequest,
    MutateCustomerUserAccessInvitationResponse,
    MutateCustomerUserAccessInvitationResult,
)
from .customer_user_access_service import (
    CustomerUserAccessOperation,
    MutateCustomerUserAccessRequest,
    MutateCustomerUserAccessResponse,
    MutateCustomerUserAccessResult,
)
from .customizer_attribute_service import (
    CustomizerAttributeOperation,
    MutateCustomizerAttributeResult,
    MutateCustomizerAttributesRequest,
    MutateCustomizerAttributesResponse,
)
from .data_link_service import (
    CreateDataLinkRequest,
    CreateDataLinkResponse,
    RemoveDataLinkRequest,
    RemoveDataLinkResponse,
    UpdateDataLinkRequest,
    UpdateDataLinkResponse,
)
from .experiment_arm_service import (
    ExperimentArmOperation,
    MutateExperimentArmResult,
    MutateExperimentArmsRequest,
    MutateExperimentArmsResponse,
)
from .experiment_service import (
    CampaignBudgetMapping,
    EndExperimentRequest,
    ExperimentOperation,
    GraduateExperimentRequest,
    ListExperimentAsyncErrorsRequest,
    ListExperimentAsyncErrorsResponse,
    MutateExperimentResult,
    MutateExperimentsRequest,
    MutateExperimentsResponse,
    PromoteExperimentMetadata,
    PromoteExperimentRequest,
    ScheduleExperimentMetadata,
    ScheduleExperimentRequest,
)
from .geo_target_constant_service import (
    GeoTargetConstantSuggestion,
    SuggestGeoTargetConstantsRequest,
    SuggestGeoTargetConstantsResponse,
)
from .goal_service import (
    GoalOperation,
    MutateGoalResult,
    MutateGoalsRequest,
    MutateGoalsResponse,
)
from .google_ads_field_service import (
    GetGoogleAdsFieldRequest,
    SearchGoogleAdsFieldsRequest,
    SearchGoogleAdsFieldsResponse,
)
from .google_ads_service import (
    GoogleAdsRow,
    MutateGoogleAdsRequest,
    MutateGoogleAdsResponse,
    MutateOperation,
    MutateOperationResponse,
    SearchGoogleAdsRequest,
    SearchGoogleAdsResponse,
    SearchGoogleAdsStreamRequest,
    SearchGoogleAdsStreamResponse,
    SearchSettings,
)
from .identity_verification_service import (
    GetIdentityVerificationRequest,
    GetIdentityVerificationResponse,
    IdentityVerification,
    IdentityVerificationProgress,
    IdentityVerificationRequirement,
    StartIdentityVerificationRequest,
)
from .invoice_service import (
    ListInvoicesRequest,
    ListInvoicesResponse,
)
from .keyword_plan_ad_group_keyword_service import (
    KeywordPlanAdGroupKeywordOperation,
    MutateKeywordPlanAdGroupKeywordResult,
    MutateKeywordPlanAdGroupKeywordsRequest,
    MutateKeywordPlanAdGroupKeywordsResponse,
)
from .keyword_plan_ad_group_service import (
    KeywordPlanAdGroupOperation,
    MutateKeywordPlanAdGroupResult,
    MutateKeywordPlanAdGroupsRequest,
    MutateKeywordPlanAdGroupsResponse,
)
from .keyword_plan_campaign_keyword_service import (
    KeywordPlanCampaignKeywordOperation,
    MutateKeywordPlanCampaignKeywordResult,
    MutateKeywordPlanCampaignKeywordsRequest,
    MutateKeywordPlanCampaignKeywordsResponse,
)
from .keyword_plan_campaign_service import (
    KeywordPlanCampaignOperation,
    MutateKeywordPlanCampaignResult,
    MutateKeywordPlanCampaignsRequest,
    MutateKeywordPlanCampaignsResponse,
)
from .keyword_plan_idea_service import (
    AdGroupKeywordSuggestion,
    BiddableKeyword,
    CampaignToForecast,
    CriterionBidModifier,
    ForecastAdGroup,
    GenerateAdGroupThemesRequest,
    GenerateAdGroupThemesResponse,
    GenerateKeywordForecastMetricsRequest,
    GenerateKeywordForecastMetricsResponse,
    GenerateKeywordHistoricalMetricsRequest,
    GenerateKeywordHistoricalMetricsResponse,
    GenerateKeywordHistoricalMetricsResult,
    GenerateKeywordIdeaResponse,
    GenerateKeywordIdeaResult,
    GenerateKeywordIdeasRequest,
    KeywordAndUrlSeed,
    KeywordForecastMetrics,
    KeywordSeed,
    ManualCpcBiddingStrategy,
    MaximizeClicksBiddingStrategy,
    MaximizeConversionsBiddingStrategy,
    SiteSeed,
    UnusableAdGroup,
    UrlSeed,
)
from .keyword_plan_service import (
    KeywordPlanOperation,
    MutateKeywordPlansRequest,
    MutateKeywordPlansResponse,
    MutateKeywordPlansResult,
)
from .keyword_theme_constant_service import (
    SuggestKeywordThemeConstantsRequest,
    SuggestKeywordThemeConstantsResponse,
)
from .label_service import (
    LabelOperation,
    MutateLabelResult,
    MutateLabelsRequest,
    MutateLabelsResponse,
)
from .local_services_lead_service import (
    AppendLeadConversationRequest,
    AppendLeadConversationResponse,
    Conversation,
    ConversationOrError,
    ProvideLeadFeedbackRequest,
    ProvideLeadFeedbackResponse,
    SurveyDissatisfied,
    SurveySatisfied,
)
from .offline_user_data_job_service import (
    AddOfflineUserDataJobOperationsRequest,
    AddOfflineUserDataJobOperationsResponse,
    CreateOfflineUserDataJobRequest,
    CreateOfflineUserDataJobResponse,
    OfflineUserDataJobOperation,
    RunOfflineUserDataJobRequest,
)
from .payments_account_service import (
    ListPaymentsAccountsRequest,
    ListPaymentsAccountsResponse,
)
from .product_link_invitation_service import (
    CreateProductLinkInvitationRequest,
    CreateProductLinkInvitationResponse,
    RemoveProductLinkInvitationRequest,
    RemoveProductLinkInvitationResponse,
    UpdateProductLinkInvitationRequest,
    UpdateProductLinkInvitationResponse,
)
from .product_link_service import (
    CreateProductLinkRequest,
    CreateProductLinkResponse,
    RemoveProductLinkRequest,
    RemoveProductLinkResponse,
)
from .reach_plan_service import (
    AdvancedProductTargeting,
    AudienceTargeting,
    CampaignDuration,
    ConversionRateSuggestion,
    EffectiveFrequencyBreakdown,
    EffectiveFrequencyLimit,
    Forecast,
    ForecastMetricOptions,
    FrequencyCap,
    GenerateConversionRatesRequest,
    GenerateConversionRatesResponse,
    GenerateReachForecastRequest,
    GenerateReachForecastResponse,
    ListPlannableLocationsRequest,
    ListPlannableLocationsResponse,
    ListPlannableProductsRequest,
    ListPlannableProductsResponse,
    ListPlannableUserInterestsRequest,
    ListPlannableUserInterestsResponse,
    ListPlannableUserListsRequest,
    ListPlannableUserListsResponse,
    OnTargetAudienceMetrics,
    PlannableLocation,
    PlannableTargeting,
    PlannableUserInterest,
    PlannableUserList,
    PlannableUserListMetadata,
    PlannedProduct,
    PlannedProductForecast,
    PlannedProductReachForecast,
    ProductMetadata,
    ReachCurve,
    ReachForecast,
    SurfaceTargeting,
    SurfaceTargetingCombinations,
    TargetFrequencySettings,
    Targeting,
    YouTubeSelectLineUp,
    YouTubeSelectSettings,
)
from .recommendation_service import (
    ApplyRecommendationOperation,
    ApplyRecommendationRequest,
    ApplyRecommendationResponse,
    ApplyRecommendationResult,
    DismissRecommendationRequest,
    DismissRecommendationResponse,
    GenerateRecommendationsRequest,
    GenerateRecommendationsResponse,
)
from .recommendation_subscription_service import (
    MutateRecommendationSubscriptionRequest,
    MutateRecommendationSubscriptionResponse,
    MutateRecommendationSubscriptionResult,
    RecommendationSubscriptionOperation,
)
from .remarketing_action_service import (
    MutateRemarketingActionResult,
    MutateRemarketingActionsRequest,
    MutateRemarketingActionsResponse,
    RemarketingActionOperation,
)
from .shareable_preview_service import (
    AssetGroupIdentifier,
    GenerateShareablePreviewsRequest,
    GenerateShareablePreviewsResponse,
    ShareablePreview,
    ShareablePreviewOrError,
    ShareablePreviewResult,
)
from .shared_criterion_service import (
    MutateSharedCriteriaRequest,
    MutateSharedCriteriaResponse,
    MutateSharedCriterionResult,
    SharedCriterionOperation,
)
from .shared_set_service import (
    MutateSharedSetResult,
    MutateSharedSetsRequest,
    MutateSharedSetsResponse,
    SharedSetOperation,
)
from .smart_campaign_setting_service import (
    GetSmartCampaignStatusRequest,
    GetSmartCampaignStatusResponse,
    MutateSmartCampaignSettingResult,
    MutateSmartCampaignSettingsRequest,
    MutateSmartCampaignSettingsResponse,
    SmartCampaignEligibleDetails,
    SmartCampaignEndedDetails,
    SmartCampaignNotEligibleDetails,
    SmartCampaignPausedDetails,
    SmartCampaignRemovedDetails,
    SmartCampaignSettingOperation,
)
from .smart_campaign_suggest_service import (
    SmartCampaignSuggestionInfo,
    SuggestKeywordThemesRequest,
    SuggestKeywordThemesResponse,
    SuggestSmartCampaignAdRequest,
    SuggestSmartCampaignAdResponse,
    SuggestSmartCampaignBudgetOptionsRequest,
    SuggestSmartCampaignBudgetOptionsResponse,
)
from .third_party_app_analytics_link_service import (
    RegenerateShareableLinkIdRequest,
    RegenerateShareableLinkIdResponse,
)
from .travel_asset_suggestion_service import (
    HotelAssetSuggestion,
    HotelImageAsset,
    HotelTextAsset,
    SuggestTravelAssetsRequest,
    SuggestTravelAssetsResponse,
)
from .user_data_service import (
    UploadUserDataRequest,
    UploadUserDataResponse,
    UserDataOperation,
)
from .user_list_customer_type_service import (
    MutateUserListCustomerTypeResult,
    MutateUserListCustomerTypesRequest,
    MutateUserListCustomerTypesResponse,
    UserListCustomerTypeOperation,
)
from .user_list_service import (
    MutateUserListResult,
    MutateUserListsRequest,
    MutateUserListsResponse,
    UserListOperation,
)

__all__ = (
    "AccountBudgetProposalOperation",
    "MutateAccountBudgetProposalRequest",
    "MutateAccountBudgetProposalResponse",
    "MutateAccountBudgetProposalResult",
    "AccountLinkOperation",
    "CreateAccountLinkRequest",
    "CreateAccountLinkResponse",
    "MutateAccountLinkRequest",
    "MutateAccountLinkResponse",
    "MutateAccountLinkResult",
    "AdGroupAdLabelOperation",
    "MutateAdGroupAdLabelResult",
    "MutateAdGroupAdLabelsRequest",
    "MutateAdGroupAdLabelsResponse",
    "AdGroupAdOperation",
    "AssetsWithFieldType",
    "MutateAdGroupAdResult",
    "MutateAdGroupAdsRequest",
    "MutateAdGroupAdsResponse",
    "RemoveAutomaticallyCreatedAssetsRequest",
    "AdGroupAssetOperation",
    "MutateAdGroupAssetResult",
    "MutateAdGroupAssetsRequest",
    "MutateAdGroupAssetsResponse",
    "AdGroupAssetSetOperation",
    "MutateAdGroupAssetSetResult",
    "MutateAdGroupAssetSetsRequest",
    "MutateAdGroupAssetSetsResponse",
    "AdGroupBidModifierOperation",
    "MutateAdGroupBidModifierResult",
    "MutateAdGroupBidModifiersRequest",
    "MutateAdGroupBidModifiersResponse",
    "AdGroupCriterionCustomizerOperation",
    "MutateAdGroupCriterionCustomizerResult",
    "MutateAdGroupCriterionCustomizersRequest",
    "MutateAdGroupCriterionCustomizersResponse",
    "AdGroupCriterionLabelOperation",
    "MutateAdGroupCriterionLabelResult",
    "MutateAdGroupCriterionLabelsRequest",
    "MutateAdGroupCriterionLabelsResponse",
    "AdGroupCriterionOperation",
    "MutateAdGroupCriteriaRequest",
    "MutateAdGroupCriteriaResponse",
    "MutateAdGroupCriterionResult",
    "AdGroupCustomizerOperation",
    "MutateAdGroupCustomizerResult",
    "MutateAdGroupCustomizersRequest",
    "MutateAdGroupCustomizersResponse",
    "AdGroupLabelOperation",
    "MutateAdGroupLabelResult",
    "MutateAdGroupLabelsRequest",
    "MutateAdGroupLabelsResponse",
    "AdGroupOperation",
    "MutateAdGroupResult",
    "MutateAdGroupsRequest",
    "MutateAdGroupsResponse",
    "AdParameterOperation",
    "MutateAdParameterResult",
    "MutateAdParametersRequest",
    "MutateAdParametersResponse",
    "AdOperation",
    "MutateAdResult",
    "MutateAdsRequest",
    "MutateAdsResponse",
    "AssetGenerationExistingContext",
    "FinalUrlImageGenerationInput",
    "FreeformImageGenerationInput",
    "GeneratedImage",
    "GeneratedText",
    "GenerateImagesRequest",
    "GenerateImagesResponse",
    "GenerateTextRequest",
    "GenerateTextResponse",
    "ProductRecontextGenerationImageInput",
    "SourceImage",
    "AssetGroupAssetOperation",
    "MutateAssetGroupAssetResult",
    "MutateAssetGroupAssetsRequest",
    "MutateAssetGroupAssetsResponse",
    "AssetGroupListingGroupFilterOperation",
    "MutateAssetGroupListingGroupFilterResult",
    "MutateAssetGroupListingGroupFiltersRequest",
    "MutateAssetGroupListingGroupFiltersResponse",
    "AssetGroupOperation",
    "MutateAssetGroupResult",
    "MutateAssetGroupsRequest",
    "MutateAssetGroupsResponse",
    "AssetGroupSignalOperation",
    "MutateAssetGroupSignalResult",
    "MutateAssetGroupSignalsRequest",
    "MutateAssetGroupSignalsResponse",
    "AssetOperation",
    "MutateAssetResult",
    "MutateAssetsRequest",
    "MutateAssetsResponse",
    "AssetSetAssetOperation",
    "MutateAssetSetAssetResult",
    "MutateAssetSetAssetsRequest",
    "MutateAssetSetAssetsResponse",
    "AssetSetOperation",
    "MutateAssetSetResult",
    "MutateAssetSetsRequest",
    "MutateAssetSetsResponse",
    "AudienceCompositionAttribute",
    "AudienceCompositionAttributeCluster",
    "AudienceCompositionMetrics",
    "AudienceCompositionSection",
    "AudienceOverlapItem",
    "DimensionOverlapResult",
    "GenerateAudienceCompositionInsightsRequest",
    "GenerateAudienceCompositionInsightsResponse",
    "GenerateAudienceOverlapInsightsRequest",
    "GenerateAudienceOverlapInsightsResponse",
    "GenerateInsightsFinderReportRequest",
    "GenerateInsightsFinderReportResponse",
    "GenerateSuggestedTargetingInsightsRequest",
    "GenerateSuggestedTargetingInsightsResponse",
    "GenerateTargetingSuggestionMetricsRequest",
    "GenerateTargetingSuggestionMetricsResponse",
    "InsightsAudience",
    "InsightsAudienceAttributeGroup",
    "InsightsAudienceDefinition",
    "InsightsAudienceDescription",
    "ListAudienceInsightsAttributesRequest",
    "ListAudienceInsightsAttributesResponse",
    "ListInsightsEligibleDatesRequest",
    "ListInsightsEligibleDatesResponse",
    "TargetingSuggestionMetrics",
    "AudienceOperation",
    "MutateAudienceResult",
    "MutateAudiencesRequest",
    "MutateAudiencesResponse",
    "RemoveCampaignAutomaticallyCreatedAssetOperation",
    "RemoveCampaignAutomaticallyCreatedAssetRequest",
    "RemoveCampaignAutomaticallyCreatedAssetResponse",
    "AddBatchJobOperationsRequest",
    "AddBatchJobOperationsResponse",
    "BatchJobOperation",
    "BatchJobResult",
    "ListBatchJobResultsRequest",
    "ListBatchJobResultsResponse",
    "MutateBatchJobRequest",
    "MutateBatchJobResponse",
    "MutateBatchJobResult",
    "RunBatchJobRequest",
    "BiddingDataExclusionOperation",
    "MutateBiddingDataExclusionsRequest",
    "MutateBiddingDataExclusionsResponse",
    "MutateBiddingDataExclusionsResult",
    "BiddingSeasonalityAdjustmentOperation",
    "MutateBiddingSeasonalityAdjustmentsRequest",
    "MutateBiddingSeasonalityAdjustmentsResponse",
    "MutateBiddingSeasonalityAdjustmentsResult",
    "BiddingStrategyOperation",
    "MutateBiddingStrategiesRequest",
    "MutateBiddingStrategiesResponse",
    "MutateBiddingStrategyResult",
    "BillingSetupOperation",
    "MutateBillingSetupRequest",
    "MutateBillingSetupResponse",
    "MutateBillingSetupResult",
    "BrandSuggestion",
    "SuggestBrandsRequest",
    "SuggestBrandsResponse",
    "CampaignAssetOperation",
    "MutateCampaignAssetResult",
    "MutateCampaignAssetsRequest",
    "MutateCampaignAssetsResponse",
    "CampaignAssetSetOperation",
    "MutateCampaignAssetSetResult",
    "MutateCampaignAssetSetsRequest",
    "MutateCampaignAssetSetsResponse",
    "CampaignBidModifierOperation",
    "MutateCampaignBidModifierResult",
    "MutateCampaignBidModifiersRequest",
    "MutateCampaignBidModifiersResponse",
    "CampaignBudgetOperation",
    "MutateCampaignBudgetResult",
    "MutateCampaignBudgetsRequest",
    "MutateCampaignBudgetsResponse",
    "CampaignConversionGoalOperation",
    "MutateCampaignConversionGoalResult",
    "MutateCampaignConversionGoalsRequest",
    "MutateCampaignConversionGoalsResponse",
    "CampaignCriterionOperation",
    "MutateCampaignCriteriaRequest",
    "MutateCampaignCriteriaResponse",
    "MutateCampaignCriterionResult",
    "CampaignCustomizerOperation",
    "MutateCampaignCustomizerResult",
    "MutateCampaignCustomizersRequest",
    "MutateCampaignCustomizersResponse",
    "CampaignDraftOperation",
    "ListCampaignDraftAsyncErrorsRequest",
    "ListCampaignDraftAsyncErrorsResponse",
    "MutateCampaignDraftResult",
    "MutateCampaignDraftsRequest",
    "MutateCampaignDraftsResponse",
    "PromoteCampaignDraftRequest",
    "CampaignGoalConfigOperation",
    "MutateCampaignGoalConfigResult",
    "MutateCampaignGoalConfigsRequest",
    "MutateCampaignGoalConfigsResponse",
    "CampaignGroupOperation",
    "MutateCampaignGroupResult",
    "MutateCampaignGroupsRequest",
    "MutateCampaignGroupsResponse",
    "CampaignLabelOperation",
    "MutateCampaignLabelResult",
    "MutateCampaignLabelsRequest",
    "MutateCampaignLabelsResponse",
    "CampaignLifecycleGoalOperation",
    "ConfigureCampaignLifecycleGoalsRequest",
    "ConfigureCampaignLifecycleGoalsResponse",
    "ConfigureCampaignLifecycleGoalsResult",
    "BrandCampaignAssets",
    "CampaignOperation",
    "EnablementResult",
    "EnableOperation",
    "EnablePMaxBrandGuidelinesRequest",
    "EnablePMaxBrandGuidelinesResponse",
    "MutateCampaignResult",
    "MutateCampaignsRequest",
    "MutateCampaignsResponse",
    "CampaignSharedSetOperation",
    "MutateCampaignSharedSetResult",
    "MutateCampaignSharedSetsRequest",
    "MutateCampaignSharedSetsResponse",
    "GenerateCreatorInsightsRequest",
    "GenerateCreatorInsightsResponse",
    "GenerateTrendingInsightsRequest",
    "GenerateTrendingInsightsResponse",
    "SearchAudience",
    "SearchTopics",
    "TrendInsight",
    "TrendInsightMetrics",
    "YouTubeChannelInsights",
    "YouTubeCreatorInsights",
    "YouTubeMetrics",
    "ConversionActionOperation",
    "MutateConversionActionResult",
    "MutateConversionActionsRequest",
    "MutateConversionActionsResponse",
    "ConversionAdjustment",
    "ConversionAdjustmentResult",
    "GclidDateTimePair",
    "RestatementValue",
    "UploadConversionAdjustmentsRequest",
    "UploadConversionAdjustmentsResponse",
    "ConversionCustomVariableOperation",
    "MutateConversionCustomVariableResult",
    "MutateConversionCustomVariablesRequest",
    "MutateConversionCustomVariablesResponse",
    "ConversionGoalCampaignConfigOperation",
    "MutateConversionGoalCampaignConfigResult",
    "MutateConversionGoalCampaignConfigsRequest",
    "MutateConversionGoalCampaignConfigsResponse",
    "CallConversion",
    "CallConversionResult",
    "CartData",
    "ClickConversion",
    "ClickConversionResult",
    "CustomVariable",
    "ExternalAttributionData",
    "SessionAttributeKeyValuePair",
    "SessionAttributesKeyValuePairs",
    "UploadCallConversionsRequest",
    "UploadCallConversionsResponse",
    "UploadClickConversionsRequest",
    "UploadClickConversionsResponse",
    "ConversionValueRuleOperation",
    "MutateConversionValueRuleResult",
    "MutateConversionValueRulesRequest",
    "MutateConversionValueRulesResponse",
    "ConversionValueRuleSetOperation",
    "MutateConversionValueRuleSetResult",
    "MutateConversionValueRuleSetsRequest",
    "MutateConversionValueRuleSetsResponse",
    "CustomAudienceOperation",
    "MutateCustomAudienceResult",
    "MutateCustomAudiencesRequest",
    "MutateCustomAudiencesResponse",
    "CustomConversionGoalOperation",
    "MutateCustomConversionGoalResult",
    "MutateCustomConversionGoalsRequest",
    "MutateCustomConversionGoalsResponse",
    "CustomInterestOperation",
    "MutateCustomInterestResult",
    "MutateCustomInterestsRequest",
    "MutateCustomInterestsResponse",
    "CustomerAssetOperation",
    "MutateCustomerAssetResult",
    "MutateCustomerAssetsRequest",
    "MutateCustomerAssetsResponse",
    "CustomerAssetSetOperation",
    "MutateCustomerAssetSetResult",
    "MutateCustomerAssetSetsRequest",
    "MutateCustomerAssetSetsResponse",
    "CustomerClientLinkOperation",
    "MutateCustomerClientLinkRequest",
    "MutateCustomerClientLinkResponse",
    "MutateCustomerClientLinkResult",
    "CustomerConversionGoalOperation",
    "MutateCustomerConversionGoalResult",
    "MutateCustomerConversionGoalsRequest",
    "MutateCustomerConversionGoalsResponse",
    "CustomerCustomizerOperation",
    "MutateCustomerCustomizerResult",
    "MutateCustomerCustomizersRequest",
    "MutateCustomerCustomizersResponse",
    "CustomerLabelOperation",
    "MutateCustomerLabelResult",
    "MutateCustomerLabelsRequest",
    "MutateCustomerLabelsResponse",
    "ConfigureCustomerLifecycleGoalsRequest",
    "ConfigureCustomerLifecycleGoalsResponse",
    "ConfigureCustomerLifecycleGoalsResult",
    "CustomerLifecycleGoalOperation",
    "CustomerManagerLinkOperation",
    "MoveManagerLinkRequest",
    "MoveManagerLinkResponse",
    "MutateCustomerManagerLinkRequest",
    "MutateCustomerManagerLinkResponse",
    "MutateCustomerManagerLinkResult",
    "CustomerNegativeCriterionOperation",
    "MutateCustomerNegativeCriteriaRequest",
    "MutateCustomerNegativeCriteriaResponse",
    "MutateCustomerNegativeCriteriaResult",
    "CreateCustomerClientRequest",
    "CreateCustomerClientResponse",
    "CustomerOperation",
    "ListAccessibleCustomersRequest",
    "ListAccessibleCustomersResponse",
    "MutateCustomerRequest",
    "MutateCustomerResponse",
    "MutateCustomerResult",
    "CustomerSkAdNetworkConversionValueSchemaOperation",
    "MutateCustomerSkAdNetworkConversionValueSchemaRequest",
    "MutateCustomerSkAdNetworkConversionValueSchemaResponse",
    "MutateCustomerSkAdNetworkConversionValueSchemaResult",
    "CustomerUserAccessInvitationOperation",
    "MutateCustomerUserAccessInvitationRequest",
    "MutateCustomerUserAccessInvitationResponse",
    "MutateCustomerUserAccessInvitationResult",
    "CustomerUserAccessOperation",
    "MutateCustomerUserAccessRequest",
    "MutateCustomerUserAccessResponse",
    "MutateCustomerUserAccessResult",
    "CustomizerAttributeOperation",
    "MutateCustomizerAttributeResult",
    "MutateCustomizerAttributesRequest",
    "MutateCustomizerAttributesResponse",
    "CreateDataLinkRequest",
    "CreateDataLinkResponse",
    "RemoveDataLinkRequest",
    "RemoveDataLinkResponse",
    "UpdateDataLinkRequest",
    "UpdateDataLinkResponse",
    "ExperimentArmOperation",
    "MutateExperimentArmResult",
    "MutateExperimentArmsRequest",
    "MutateExperimentArmsResponse",
    "CampaignBudgetMapping",
    "EndExperimentRequest",
    "ExperimentOperation",
    "GraduateExperimentRequest",
    "ListExperimentAsyncErrorsRequest",
    "ListExperimentAsyncErrorsResponse",
    "MutateExperimentResult",
    "MutateExperimentsRequest",
    "MutateExperimentsResponse",
    "PromoteExperimentMetadata",
    "PromoteExperimentRequest",
    "ScheduleExperimentMetadata",
    "ScheduleExperimentRequest",
    "GeoTargetConstantSuggestion",
    "SuggestGeoTargetConstantsRequest",
    "SuggestGeoTargetConstantsResponse",
    "GoalOperation",
    "MutateGoalResult",
    "MutateGoalsRequest",
    "MutateGoalsResponse",
    "GetGoogleAdsFieldRequest",
    "SearchGoogleAdsFieldsRequest",
    "SearchGoogleAdsFieldsResponse",
    "GoogleAdsRow",
    "MutateGoogleAdsRequest",
    "MutateGoogleAdsResponse",
    "MutateOperation",
    "MutateOperationResponse",
    "SearchGoogleAdsRequest",
    "SearchGoogleAdsResponse",
    "SearchGoogleAdsStreamRequest",
    "SearchGoogleAdsStreamResponse",
    "SearchSettings",
    "GetIdentityVerificationRequest",
    "GetIdentityVerificationResponse",
    "IdentityVerification",
    "IdentityVerificationProgress",
    "IdentityVerificationRequirement",
    "StartIdentityVerificationRequest",
    "ListInvoicesRequest",
    "ListInvoicesResponse",
    "KeywordPlanAdGroupKeywordOperation",
    "MutateKeywordPlanAdGroupKeywordResult",
    "MutateKeywordPlanAdGroupKeywordsRequest",
    "MutateKeywordPlanAdGroupKeywordsResponse",
    "KeywordPlanAdGroupOperation",
    "MutateKeywordPlanAdGroupResult",
    "MutateKeywordPlanAdGroupsRequest",
    "MutateKeywordPlanAdGroupsResponse",
    "KeywordPlanCampaignKeywordOperation",
    "MutateKeywordPlanCampaignKeywordResult",
    "MutateKeywordPlanCampaignKeywordsRequest",
    "MutateKeywordPlanCampaignKeywordsResponse",
    "KeywordPlanCampaignOperation",
    "MutateKeywordPlanCampaignResult",
    "MutateKeywordPlanCampaignsRequest",
    "MutateKeywordPlanCampaignsResponse",
    "AdGroupKeywordSuggestion",
    "BiddableKeyword",
    "CampaignToForecast",
    "CriterionBidModifier",
    "ForecastAdGroup",
    "GenerateAdGroupThemesRequest",
    "GenerateAdGroupThemesResponse",
    "GenerateKeywordForecastMetricsRequest",
    "GenerateKeywordForecastMetricsResponse",
    "GenerateKeywordHistoricalMetricsRequest",
    "GenerateKeywordHistoricalMetricsResponse",
    "GenerateKeywordHistoricalMetricsResult",
    "GenerateKeywordIdeaResponse",
    "GenerateKeywordIdeaResult",
    "GenerateKeywordIdeasRequest",
    "KeywordAndUrlSeed",
    "KeywordForecastMetrics",
    "KeywordSeed",
    "ManualCpcBiddingStrategy",
    "MaximizeClicksBiddingStrategy",
    "MaximizeConversionsBiddingStrategy",
    "SiteSeed",
    "UnusableAdGroup",
    "UrlSeed",
    "KeywordPlanOperation",
    "MutateKeywordPlansRequest",
    "MutateKeywordPlansResponse",
    "MutateKeywordPlansResult",
    "SuggestKeywordThemeConstantsRequest",
    "SuggestKeywordThemeConstantsResponse",
    "LabelOperation",
    "MutateLabelResult",
    "MutateLabelsRequest",
    "MutateLabelsResponse",
    "AppendLeadConversationRequest",
    "AppendLeadConversationResponse",
    "Conversation",
    "ConversationOrError",
    "ProvideLeadFeedbackRequest",
    "ProvideLeadFeedbackResponse",
    "SurveyDissatisfied",
    "SurveySatisfied",
    "AddOfflineUserDataJobOperationsRequest",
    "AddOfflineUserDataJobOperationsResponse",
    "CreateOfflineUserDataJobRequest",
    "CreateOfflineUserDataJobResponse",
    "OfflineUserDataJobOperation",
    "RunOfflineUserDataJobRequest",
    "ListPaymentsAccountsRequest",
    "ListPaymentsAccountsResponse",
    "CreateProductLinkInvitationRequest",
    "CreateProductLinkInvitationResponse",
    "RemoveProductLinkInvitationRequest",
    "RemoveProductLinkInvitationResponse",
    "UpdateProductLinkInvitationRequest",
    "UpdateProductLinkInvitationResponse",
    "CreateProductLinkRequest",
    "CreateProductLinkResponse",
    "RemoveProductLinkRequest",
    "RemoveProductLinkResponse",
    "AdvancedProductTargeting",
    "AudienceTargeting",
    "CampaignDuration",
    "ConversionRateSuggestion",
    "EffectiveFrequencyBreakdown",
    "EffectiveFrequencyLimit",
    "Forecast",
    "ForecastMetricOptions",
    "FrequencyCap",
    "GenerateConversionRatesRequest",
    "GenerateConversionRatesResponse",
    "GenerateReachForecastRequest",
    "GenerateReachForecastResponse",
    "ListPlannableLocationsRequest",
    "ListPlannableLocationsResponse",
    "ListPlannableProductsRequest",
    "ListPlannableProductsResponse",
    "ListPlannableUserInterestsRequest",
    "ListPlannableUserInterestsResponse",
    "ListPlannableUserListsRequest",
    "ListPlannableUserListsResponse",
    "OnTargetAudienceMetrics",
    "PlannableLocation",
    "PlannableTargeting",
    "PlannableUserInterest",
    "PlannableUserList",
    "PlannableUserListMetadata",
    "PlannedProduct",
    "PlannedProductForecast",
    "PlannedProductReachForecast",
    "ProductMetadata",
    "ReachCurve",
    "ReachForecast",
    "SurfaceTargeting",
    "SurfaceTargetingCombinations",
    "TargetFrequencySettings",
    "Targeting",
    "YouTubeSelectLineUp",
    "YouTubeSelectSettings",
    "ApplyRecommendationOperation",
    "ApplyRecommendationRequest",
    "ApplyRecommendationResponse",
    "ApplyRecommendationResult",
    "DismissRecommendationRequest",
    "DismissRecommendationResponse",
    "GenerateRecommendationsRequest",
    "GenerateRecommendationsResponse",
    "MutateRecommendationSubscriptionRequest",
    "MutateRecommendationSubscriptionResponse",
    "MutateRecommendationSubscriptionResult",
    "RecommendationSubscriptionOperation",
    "MutateRemarketingActionResult",
    "MutateRemarketingActionsRequest",
    "MutateRemarketingActionsResponse",
    "RemarketingActionOperation",
    "AssetGroupIdentifier",
    "GenerateShareablePreviewsRequest",
    "GenerateShareablePreviewsResponse",
    "ShareablePreview",
    "ShareablePreviewOrError",
    "ShareablePreviewResult",
    "MutateSharedCriteriaRequest",
    "MutateSharedCriteriaResponse",
    "MutateSharedCriterionResult",
    "SharedCriterionOperation",
    "MutateSharedSetResult",
    "MutateSharedSetsRequest",
    "MutateSharedSetsResponse",
    "SharedSetOperation",
    "GetSmartCampaignStatusRequest",
    "GetSmartCampaignStatusResponse",
    "MutateSmartCampaignSettingResult",
    "MutateSmartCampaignSettingsRequest",
    "MutateSmartCampaignSettingsResponse",
    "SmartCampaignEligibleDetails",
    "SmartCampaignEndedDetails",
    "SmartCampaignNotEligibleDetails",
    "SmartCampaignPausedDetails",
    "SmartCampaignRemovedDetails",
    "SmartCampaignSettingOperation",
    "SmartCampaignSuggestionInfo",
    "SuggestKeywordThemesRequest",
    "SuggestKeywordThemesResponse",
    "SuggestSmartCampaignAdRequest",
    "SuggestSmartCampaignAdResponse",
    "SuggestSmartCampaignBudgetOptionsRequest",
    "SuggestSmartCampaignBudgetOptionsResponse",
    "RegenerateShareableLinkIdRequest",
    "RegenerateShareableLinkIdResponse",
    "HotelAssetSuggestion",
    "HotelImageAsset",
    "HotelTextAsset",
    "SuggestTravelAssetsRequest",
    "SuggestTravelAssetsResponse",
    "UploadUserDataRequest",
    "UploadUserDataResponse",
    "UserDataOperation",
    "MutateUserListCustomerTypeResult",
    "MutateUserListCustomerTypesRequest",
    "MutateUserListCustomerTypesResponse",
    "UserListCustomerTypeOperation",
    "MutateUserListResult",
    "MutateUserListsRequest",
    "MutateUserListsResponse",
    "UserListOperation",
)
