# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations


import proto  # type: ignore


__protobuf__ = proto.module(
    package="google.ads.googleads.v20.resources",
    marshal="google.ads.googleads.v20",
    manifest={
        "GenderView",
    },
)


class GenderView(proto.Message):
    r"""A gender view. The gender_view resource reflects the effective
    serving state, rather than what criteria were added. An ad group
    without gender criteria by default shows to all genders, so all
    genders appear in gender_view with stats.

    Attributes:
        resource_name (str):
            Output only. The resource name of the gender view. Gender
            view resource names have the form:

            ``customers/{customer_id}/genderViews/{ad_group_id}~{criterion_id}``
    """

    resource_name: str = proto.Field(
        proto.STRING,
        number=1,
    )


__all__ = tuple(sorted(__protobuf__.manifest))
