# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations


import proto  # type: ignore


__protobuf__ = proto.module(
    package="google.ads.googleads.v19.errors",
    marshal="google.ads.googleads.v19",
    manifest={
        "SizeLimitErrorEnum",
    },
)


class SizeLimitErrorEnum(proto.Message):
    r"""Container for enum describing possible size limit errors."""

    class SizeLimitError(proto.Enum):
        r"""Enum describing possible size limit errors.

        Values:
            UNSPECIFIED (0):
                Enum unspecified.
            UNKNOWN (1):
                The received error code is not known in this
                version.
            REQUEST_SIZE_LIMIT_EXCEEDED (2):
                The number of entries in the request exceeds
                the system limit, or the contents of the
                operations exceed transaction limits due to
                their size or complexity. Try reducing the
                number of entries per request.
            RESPONSE_SIZE_LIMIT_EXCEEDED (3):
                The number of entries in the response exceeds
                the system limit.
        """

        UNSPECIFIED = 0
        UNKNOWN = 1
        REQUEST_SIZE_LIMIT_EXCEEDED = 2
        RESPONSE_SIZE_LIMIT_EXCEEDED = 3


__all__ = tuple(sorted(__protobuf__.manifest))
