# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations


import proto  # type: ignore


__protobuf__ = proto.module(
    package="google.ads.googleads.v19.enums",
    marshal="google.ads.googleads.v19",
    manifest={
        "SearchTermMatchTypeEnum",
    },
)


class SearchTermMatchTypeEnum(proto.Message):
    r"""Container for enum describing match types for a keyword
    triggering an ad.

    """

    class SearchTermMatchType(proto.Enum):
        r"""Possible match types for a keyword triggering an ad,
        including variants.

        Values:
            UNSPECIFIED (0):
                Not specified.
            UNKNOWN (1):
                Used for return value only. Represents value
                unknown in this version.
            BROAD (2):
                Broad match.
            EXACT (3):
                Exact match.
            PHRASE (4):
                Phrase match.
            NEAR_EXACT (5):
                Exact match (close variant).
            NEAR_PHRASE (6):
                Phrase match (close variant).
        """

        UNSPECIFIED = 0
        UNKNOWN = 1
        BROAD = 2
        EXACT = 3
        PHRASE = 4
        NEAR_EXACT = 5
        NEAR_PHRASE = 6


__all__ = tuple(sorted(__protobuf__.manifest))
