# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .access_invitation_error import (
    AccessInvitationErrorEnum,
)
from .account_budget_proposal_error import (
    AccountBudgetProposalErrorEnum,
)
from .account_link_error import (
    AccountLinkErrorEnum,
)
from .ad_customizer_error import (
    AdCustomizerErrorEnum,
)
from .ad_error import (
    AdErrorEnum,
)
from .ad_group_ad_error import (
    AdGroupAdErrorEnum,
)
from .ad_group_bid_modifier_error import (
    AdGroupBidModifierErrorEnum,
)
from .ad_group_criterion_customizer_error import (
    AdGroupCriterionCustomizerErrorEnum,
)
from .ad_group_criterion_error import (
    AdGroupCriterionErrorEnum,
)
from .ad_group_customizer_error import (
    AdGroupCustomizerErrorEnum,
)
from .ad_group_error import (
    AdGroupErrorEnum,
)
from .ad_group_feed_error import (
    AdGroupFeedErrorEnum,
)
from .ad_parameter_error import (
    AdParameterErrorEnum,
)
from .ad_sharing_error import (
    AdSharingErrorEnum,
)
from .adx_error import (
    AdxErrorEnum,
)
from .asset_error import (
    AssetErrorEnum,
)
from .asset_group_asset_error import (
    AssetGroupAssetErrorEnum,
)
from .asset_group_error import (
    AssetGroupErrorEnum,
)
from .asset_group_listing_group_filter_error import (
    AssetGroupListingGroupFilterErrorEnum,
)
from .asset_group_signal_error import (
    AssetGroupSignalErrorEnum,
)
from .asset_link_error import (
    AssetLinkErrorEnum,
)
from .asset_set_asset_error import (
    AssetSetAssetErrorEnum,
)
from .asset_set_error import (
    AssetSetErrorEnum,
)
from .asset_set_link_error import (
    AssetSetLinkErrorEnum,
)
from .audience_error import (
    AudienceErrorEnum,
)
from .audience_insights_error import (
    AudienceInsightsErrorEnum,
)
from .authentication_error import (
    AuthenticationErrorEnum,
)
from .authorization_error import (
    AuthorizationErrorEnum,
)
from .automatically_created_asset_removal_error import (
    AutomaticallyCreatedAssetRemovalErrorEnum,
)
from .batch_job_error import (
    BatchJobErrorEnum,
)
from .bidding_error import (
    BiddingErrorEnum,
)
from .bidding_strategy_error import (
    BiddingStrategyErrorEnum,
)
from .billing_setup_error import (
    BillingSetupErrorEnum,
)
from .brand_guidelines_migration_error import (
    BrandGuidelinesMigrationErrorEnum,
)
from .campaign_budget_error import (
    CampaignBudgetErrorEnum,
)
from .campaign_conversion_goal_error import (
    CampaignConversionGoalErrorEnum,
)
from .campaign_criterion_error import (
    CampaignCriterionErrorEnum,
)
from .campaign_customizer_error import (
    CampaignCustomizerErrorEnum,
)
from .campaign_draft_error import (
    CampaignDraftErrorEnum,
)
from .campaign_error import (
    CampaignErrorEnum,
)
from .campaign_experiment_error import (
    CampaignExperimentErrorEnum,
)
from .campaign_feed_error import (
    CampaignFeedErrorEnum,
)
from .campaign_lifecycle_goal_error import (
    CampaignLifecycleGoalErrorEnum,
)
from .campaign_shared_set_error import (
    CampaignSharedSetErrorEnum,
)
from .change_event_error import (
    ChangeEventErrorEnum,
)
from .change_status_error import (
    ChangeStatusErrorEnum,
)
from .collection_size_error import (
    CollectionSizeErrorEnum,
)
from .context_error import (
    ContextErrorEnum,
)
from .conversion_action_error import (
    ConversionActionErrorEnum,
)
from .conversion_adjustment_upload_error import (
    ConversionAdjustmentUploadErrorEnum,
)
from .conversion_custom_variable_error import (
    ConversionCustomVariableErrorEnum,
)
from .conversion_goal_campaign_config_error import (
    ConversionGoalCampaignConfigErrorEnum,
)
from .conversion_upload_error import (
    ConversionUploadErrorEnum,
)
from .conversion_value_rule_error import (
    ConversionValueRuleErrorEnum,
)
from .conversion_value_rule_set_error import (
    ConversionValueRuleSetErrorEnum,
)
from .country_code_error import (
    CountryCodeErrorEnum,
)
from .criterion_error import (
    CriterionErrorEnum,
)
from .currency_code_error import (
    CurrencyCodeErrorEnum,
)
from .currency_error import (
    CurrencyErrorEnum,
)
from .custom_audience_error import (
    CustomAudienceErrorEnum,
)
from .custom_conversion_goal_error import (
    CustomConversionGoalErrorEnum,
)
from .custom_interest_error import (
    CustomInterestErrorEnum,
)
from .customer_client_link_error import (
    CustomerClientLinkErrorEnum,
)
from .customer_customizer_error import (
    CustomerCustomizerErrorEnum,
)
from .customer_error import (
    CustomerErrorEnum,
)
from .customer_feed_error import (
    CustomerFeedErrorEnum,
)
from .customer_lifecycle_goal_error import (
    CustomerLifecycleGoalErrorEnum,
)
from .customer_manager_link_error import (
    CustomerManagerLinkErrorEnum,
)
from .customer_sk_ad_network_conversion_value_schema_error import (
    CustomerSkAdNetworkConversionValueSchemaErrorEnum,
)
from .customer_user_access_error import (
    CustomerUserAccessErrorEnum,
)
from .customizer_attribute_error import (
    CustomizerAttributeErrorEnum,
)
from .data_link_error import (
    DataLinkErrorEnum,
)
from .database_error import (
    DatabaseErrorEnum,
)
from .date_error import (
    DateErrorEnum,
)
from .date_range_error import (
    DateRangeErrorEnum,
)
from .distinct_error import (
    DistinctErrorEnum,
)
from .enum_error import (
    EnumErrorEnum,
)
from .errors import (
    ErrorCode,
    ErrorDetails,
    ErrorLocation,
    GoogleAdsError,
    GoogleAdsFailure,
    PolicyFindingDetails,
    PolicyViolationDetails,
    QuotaErrorDetails,
    ResourceCountDetails,
)
from .experiment_arm_error import (
    ExperimentArmErrorEnum,
)
from .experiment_error import (
    ExperimentErrorEnum,
)
from .extension_feed_item_error import (
    ExtensionFeedItemErrorEnum,
)
from .extension_setting_error import (
    ExtensionSettingErrorEnum,
)
from .feed_attribute_reference_error import (
    FeedAttributeReferenceErrorEnum,
)
from .feed_error import (
    FeedErrorEnum,
)
from .feed_item_error import (
    FeedItemErrorEnum,
)
from .feed_item_set_error import (
    FeedItemSetErrorEnum,
)
from .feed_item_set_link_error import (
    FeedItemSetLinkErrorEnum,
)
from .feed_item_target_error import (
    FeedItemTargetErrorEnum,
)
from .feed_item_validation_error import (
    FeedItemValidationErrorEnum,
)
from .feed_mapping_error import (
    FeedMappingErrorEnum,
)
from .field_error import (
    FieldErrorEnum,
)
from .field_mask_error import (
    FieldMaskErrorEnum,
)
from .function_error import (
    FunctionErrorEnum,
)
from .function_parsing_error import (
    FunctionParsingErrorEnum,
)
from .geo_target_constant_suggestion_error import (
    GeoTargetConstantSuggestionErrorEnum,
)
from .header_error import (
    HeaderErrorEnum,
)
from .id_error import (
    IdErrorEnum,
)
from .identity_verification_error import (
    IdentityVerificationErrorEnum,
)
from .image_error import (
    ImageErrorEnum,
)
from .internal_error import (
    InternalErrorEnum,
)
from .invoice_error import (
    InvoiceErrorEnum,
)
from .keyword_plan_ad_group_error import (
    KeywordPlanAdGroupErrorEnum,
)
from .keyword_plan_ad_group_keyword_error import (
    KeywordPlanAdGroupKeywordErrorEnum,
)
from .keyword_plan_campaign_error import (
    KeywordPlanCampaignErrorEnum,
)
from .keyword_plan_campaign_keyword_error import (
    KeywordPlanCampaignKeywordErrorEnum,
)
from .keyword_plan_error import (
    KeywordPlanErrorEnum,
)
from .keyword_plan_idea_error import (
    KeywordPlanIdeaErrorEnum,
)
from .label_error import (
    LabelErrorEnum,
)
from .language_code_error import (
    LanguageCodeErrorEnum,
)
from .list_operation_error import (
    ListOperationErrorEnum,
)
from .manager_link_error import (
    ManagerLinkErrorEnum,
)
from .media_bundle_error import (
    MediaBundleErrorEnum,
)
from .media_file_error import (
    MediaFileErrorEnum,
)
from .media_upload_error import (
    MediaUploadErrorEnum,
)
from .merchant_center_error import (
    MerchantCenterErrorEnum,
)
from .multiplier_error import (
    MultiplierErrorEnum,
)
from .mutate_error import (
    MutateErrorEnum,
)
from .new_resource_creation_error import (
    NewResourceCreationErrorEnum,
)
from .not_allowlisted_error import (
    NotAllowlistedErrorEnum,
)
from .not_empty_error import (
    NotEmptyErrorEnum,
)
from .null_error import (
    NullErrorEnum,
)
from .offline_user_data_job_error import (
    OfflineUserDataJobErrorEnum,
)
from .operation_access_denied_error import (
    OperationAccessDeniedErrorEnum,
)
from .operator_error import (
    OperatorErrorEnum,
)
from .partial_failure_error import (
    PartialFailureErrorEnum,
)
from .payments_account_error import (
    PaymentsAccountErrorEnum,
)
from .policy_finding_error import (
    PolicyFindingErrorEnum,
)
from .policy_validation_parameter_error import (
    PolicyValidationParameterErrorEnum,
)
from .policy_violation_error import (
    PolicyViolationErrorEnum,
)
from .product_link_error import (
    ProductLinkErrorEnum,
)
from .product_link_invitation_error import (
    ProductLinkInvitationErrorEnum,
)
from .query_error import (
    QueryErrorEnum,
)
from .quota_error import (
    QuotaErrorEnum,
)
from .range_error import (
    RangeErrorEnum,
)
from .reach_plan_error import (
    ReachPlanErrorEnum,
)
from .recommendation_error import (
    RecommendationErrorEnum,
)
from .recommendation_subscription_error import (
    RecommendationSubscriptionErrorEnum,
)
from .region_code_error import (
    RegionCodeErrorEnum,
)
from .request_error import (
    RequestErrorEnum,
)
from .resource_access_denied_error import (
    ResourceAccessDeniedErrorEnum,
)
from .resource_count_limit_exceeded_error import (
    ResourceCountLimitExceededErrorEnum,
)
from .search_term_insight_error import (
    SearchTermInsightErrorEnum,
)
from .setting_error import (
    SettingErrorEnum,
)
from .shareable_preview_error import (
    ShareablePreviewErrorEnum,
)
from .shared_criterion_error import (
    SharedCriterionErrorEnum,
)
from .shared_set_error import (
    SharedSetErrorEnum,
)
from .shopping_product_error import (
    ShoppingProductErrorEnum,
)
from .size_limit_error import (
    SizeLimitErrorEnum,
)
from .smart_campaign_error import (
    SmartCampaignErrorEnum,
)
from .string_format_error import (
    StringFormatErrorEnum,
)
from .string_length_error import (
    StringLengthErrorEnum,
)
from .third_party_app_analytics_link_error import (
    ThirdPartyAppAnalyticsLinkErrorEnum,
)
from .time_zone_error import (
    TimeZoneErrorEnum,
)
from .url_field_error import (
    UrlFieldErrorEnum,
)
from .user_data_error import (
    UserDataErrorEnum,
)
from .user_list_customer_type_error import (
    UserListCustomerTypeErrorEnum,
)
from .user_list_error import (
    UserListErrorEnum,
)
from .video_campaign_error import (
    VideoCampaignErrorEnum,
)
from .youtube_video_registration_error import (
    YoutubeVideoRegistrationErrorEnum,
)

__all__ = (
    "AccessInvitationErrorEnum",
    "AccountBudgetProposalErrorEnum",
    "AccountLinkErrorEnum",
    "AdCustomizerErrorEnum",
    "AdErrorEnum",
    "AdGroupAdErrorEnum",
    "AdGroupBidModifierErrorEnum",
    "AdGroupCriterionCustomizerErrorEnum",
    "AdGroupCriterionErrorEnum",
    "AdGroupCustomizerErrorEnum",
    "AdGroupErrorEnum",
    "AdGroupFeedErrorEnum",
    "AdParameterErrorEnum",
    "AdSharingErrorEnum",
    "AdxErrorEnum",
    "AssetErrorEnum",
    "AssetGroupAssetErrorEnum",
    "AssetGroupErrorEnum",
    "AssetGroupListingGroupFilterErrorEnum",
    "AssetGroupSignalErrorEnum",
    "AssetLinkErrorEnum",
    "AssetSetAssetErrorEnum",
    "AssetSetErrorEnum",
    "AssetSetLinkErrorEnum",
    "AudienceErrorEnum",
    "AudienceInsightsErrorEnum",
    "AuthenticationErrorEnum",
    "AuthorizationErrorEnum",
    "AutomaticallyCreatedAssetRemovalErrorEnum",
    "BatchJobErrorEnum",
    "BiddingErrorEnum",
    "BiddingStrategyErrorEnum",
    "BillingSetupErrorEnum",
    "BrandGuidelinesMigrationErrorEnum",
    "CampaignBudgetErrorEnum",
    "CampaignConversionGoalErrorEnum",
    "CampaignCriterionErrorEnum",
    "CampaignCustomizerErrorEnum",
    "CampaignDraftErrorEnum",
    "CampaignErrorEnum",
    "CampaignExperimentErrorEnum",
    "CampaignFeedErrorEnum",
    "CampaignLifecycleGoalErrorEnum",
    "CampaignSharedSetErrorEnum",
    "ChangeEventErrorEnum",
    "ChangeStatusErrorEnum",
    "CollectionSizeErrorEnum",
    "ContextErrorEnum",
    "ConversionActionErrorEnum",
    "ConversionAdjustmentUploadErrorEnum",
    "ConversionCustomVariableErrorEnum",
    "ConversionGoalCampaignConfigErrorEnum",
    "ConversionUploadErrorEnum",
    "ConversionValueRuleErrorEnum",
    "ConversionValueRuleSetErrorEnum",
    "CountryCodeErrorEnum",
    "CriterionErrorEnum",
    "CurrencyCodeErrorEnum",
    "CurrencyErrorEnum",
    "CustomAudienceErrorEnum",
    "CustomConversionGoalErrorEnum",
    "CustomInterestErrorEnum",
    "CustomerClientLinkErrorEnum",
    "CustomerCustomizerErrorEnum",
    "CustomerErrorEnum",
    "CustomerFeedErrorEnum",
    "CustomerLifecycleGoalErrorEnum",
    "CustomerManagerLinkErrorEnum",
    "CustomerSkAdNetworkConversionValueSchemaErrorEnum",
    "CustomerUserAccessErrorEnum",
    "CustomizerAttributeErrorEnum",
    "DataLinkErrorEnum",
    "DatabaseErrorEnum",
    "DateErrorEnum",
    "DateRangeErrorEnum",
    "DistinctErrorEnum",
    "EnumErrorEnum",
    "ErrorCode",
    "ErrorDetails",
    "ErrorLocation",
    "GoogleAdsError",
    "GoogleAdsFailure",
    "PolicyFindingDetails",
    "PolicyViolationDetails",
    "QuotaErrorDetails",
    "ResourceCountDetails",
    "ExperimentArmErrorEnum",
    "ExperimentErrorEnum",
    "ExtensionFeedItemErrorEnum",
    "ExtensionSettingErrorEnum",
    "FeedAttributeReferenceErrorEnum",
    "FeedErrorEnum",
    "FeedItemErrorEnum",
    "FeedItemSetErrorEnum",
    "FeedItemSetLinkErrorEnum",
    "FeedItemTargetErrorEnum",
    "FeedItemValidationErrorEnum",
    "FeedMappingErrorEnum",
    "FieldErrorEnum",
    "FieldMaskErrorEnum",
    "FunctionErrorEnum",
    "FunctionParsingErrorEnum",
    "GeoTargetConstantSuggestionErrorEnum",
    "HeaderErrorEnum",
    "IdErrorEnum",
    "IdentityVerificationErrorEnum",
    "ImageErrorEnum",
    "InternalErrorEnum",
    "InvoiceErrorEnum",
    "KeywordPlanAdGroupErrorEnum",
    "KeywordPlanAdGroupKeywordErrorEnum",
    "KeywordPlanCampaignErrorEnum",
    "KeywordPlanCampaignKeywordErrorEnum",
    "KeywordPlanErrorEnum",
    "KeywordPlanIdeaErrorEnum",
    "LabelErrorEnum",
    "LanguageCodeErrorEnum",
    "ListOperationErrorEnum",
    "ManagerLinkErrorEnum",
    "MediaBundleErrorEnum",
    "MediaFileErrorEnum",
    "MediaUploadErrorEnum",
    "MerchantCenterErrorEnum",
    "MultiplierErrorEnum",
    "MutateErrorEnum",
    "NewResourceCreationErrorEnum",
    "NotAllowlistedErrorEnum",
    "NotEmptyErrorEnum",
    "NullErrorEnum",
    "OfflineUserDataJobErrorEnum",
    "OperationAccessDeniedErrorEnum",
    "OperatorErrorEnum",
    "PartialFailureErrorEnum",
    "PaymentsAccountErrorEnum",
    "PolicyFindingErrorEnum",
    "PolicyValidationParameterErrorEnum",
    "PolicyViolationErrorEnum",
    "ProductLinkErrorEnum",
    "ProductLinkInvitationErrorEnum",
    "QueryErrorEnum",
    "QuotaErrorEnum",
    "RangeErrorEnum",
    "ReachPlanErrorEnum",
    "RecommendationErrorEnum",
    "RecommendationSubscriptionErrorEnum",
    "RegionCodeErrorEnum",
    "RequestErrorEnum",
    "ResourceAccessDeniedErrorEnum",
    "ResourceCountLimitExceededErrorEnum",
    "SearchTermInsightErrorEnum",
    "SettingErrorEnum",
    "ShareablePreviewErrorEnum",
    "SharedCriterionErrorEnum",
    "SharedSetErrorEnum",
    "ShoppingProductErrorEnum",
    "SizeLimitErrorEnum",
    "SmartCampaignErrorEnum",
    "StringFormatErrorEnum",
    "StringLengthErrorEnum",
    "ThirdPartyAppAnalyticsLinkErrorEnum",
    "TimeZoneErrorEnum",
    "UrlFieldErrorEnum",
    "UserDataErrorEnum",
    "UserListCustomerTypeErrorEnum",
    "UserListErrorEnum",
    "VideoCampaignErrorEnum",
    "YoutubeVideoRegistrationErrorEnum",
)
